#ifndef PLASMA_STDIN_H
#define PLASMA_STDIN_H

#include <Plasma/Applet>
#include <Plasma/Svg>
#include <QProcess>
#include <QList>
#include <QAction>

class ConfigDialog;

class PlasmaStdin : public Plasma::Applet {
    Q_OBJECT

public:
    PlasmaStdin(QObject *parent, const QVariantList &args);
    virtual ~PlasmaStdin();

    void paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *option, const QRect& contentsRect);

    void init();

    void loadConfig();

    void saveConfig();

    //void showConfigurationInterface();
    void createConfigurationInterface( KConfigDialog* );

    QList<QAction*> contextualActions();

    void setFont(QFont font) {
        m_font = font;
	Plasma::Applet::setFont(font);
    }

    QFont font() const {
        return m_font;
    }
	
    void setColor(QColor color) {
        m_color = color;
    }

    QColor color() const {
        return m_color;
    }

    void setCommand(QString cmd) {
        m_cmd = cmd;
    }

    QString command() const {
        return m_cmd;
    }

    void setTimeout(int timeout) {
        m_timeout = timeout;
    }

    int timeout() const {
        return m_timeout;
    }

    void setFixed(bool fixed) {
        m_fixed = fixed;
    }

    bool isFixed() const {
        return m_fixed;
    }

    int allignment() const {
	    return m_align;
    }
    
    void setAllignment(int align) {
	    m_align = align;
    }
	
    void constraintsEvent(Plasma::Constraints constraints);

public slots:
    void readFromStdout();

    void updateCommand(int exitCode, QProcess::ExitStatus exitStatus);

    void runCommand();
    
private slots:
      void copy() const;
      void settingsChanged();

private:
    QFont         m_font;
    bool          m_fixed;
    int           m_timeout, m_align, m_alignVert;
    QColor        m_color;
    QString       m_cmd, m_mess;
    QProcess     *m_proc;
    QTimer       *m_timer;
    Plasma::Svg   m_svg;
    ConfigDialog *m_cdiag;
    QRect         m_rect;
    QList<QAction *> m_actions;
    bool          m_inPanel;

    void realize();
};

#endif
