/* This file is part of Stdin plasmoid.
 * Copyright (c) 2008 Ruan Strydom <ruans@kr8.co.za>
 * Copyright (C) 2009 Ezequiel R. Aguerre <ezeaguerre@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
#ifndef __CONFIG__H__
#define __CONFIG__H__

#include <QObject>
#include <Plasma/Applet>
#include "ui_settings.h"
#include "ui_theme.h"
#include "options.h"

class KConfigDialog;

class Config : public QObject
{
	Q_OBJECT
	public:
		Config ( KConfigDialog * );
		~Config ();
	
		// Appearence
		QFont font () const { return m_theme.fontRequester->font (); }
		QColor color () const { return m_theme.btnColor->color (); }
		int alignment () const;
		int background () const;
		bool breakLines () const { return m_theme.chkBreak->isEnabled () && m_theme.chkBreak->isChecked (); }
		bool isFixed () const { return m_theme.chkFixed->isChecked (); }
		
		// Settings
		int timer () const { return m_settings.intTimer->value (); }
		int lines () const { return m_settings.intLines->value (); }
		QString action () const { return isCommand() ? m_settings.comboCommand->currentText () : m_settings.urlFile->url ().url (); }
		bool isCommand () const { return m_settings.radioCommand->isChecked (); }
		
		void fillOptions ( Options & ) const;
		void fillFromOptions ( const Options & );
	
	private slots:
		void updateUI ();
	
	private:
		Ui::Settings m_settings;
		Ui::Theme m_theme;
		KConfigDialog *m_parent;
};

#endif