/* This file is part of Stdin plasmoid.
 * Copyright (c) 2008 Ruan Strydom <ruans@kr8.co.za>
 * Copyright (C) 2009 Ezequiel R. Aguerre <ezeaguerre@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
#ifndef __STDIN__H__
#define __STDIN__H__

#include <Plasma/PopupApplet>
#include <QString>
#include <KProcess>
#include <QList>
#include "label.h"
#include "options.h"

class Config;
class QTimer;
class KJob;
class QAction;
class KAboutData;
namespace KIO { class TransferJob; }

class Stdin : public Plasma::PopupApplet {
	Q_OBJECT
	public:
		Stdin (QObject *, const QVariantList &);
		~Stdin ();

		void init ();
		QGraphicsWidget *graphicsWidget () { return m_label; }

		void createConfigurationInterface ( KConfigDialog *parent );
		QList<QAction *> contextualActions () { return m_actions; }

	private slots:
		void dialogConfigAccepted ();
		void timeout ();
		void updateBackground (); // FIXME: This is for a workaround, see Stdin::Init()
		
		// Contextual Actions
		void copy () const;
		void about () const;
		void refresh ();
		void bugReport () const;

		// Process related
		void readDataOutput ();
		void readDataError ();
		void runCommand ();
		void processFinished (int, QProcess::ExitStatus);
		void processError ( QProcess::ProcessError );
		
		// File related
		void getFile ();
		void readDataFile ( KIO::Job *, const QByteArray & );
		void finishedFile ( KJob * );

	private:
		KAboutData *m_aboutData;
		Label  *m_label;
		Config *m_configDialog;
		Options m_options;
		
		KProcess *m_process;
		QTimer   *m_timer;
		QString   m_error; /**< An error message if the process or file read fails */
		
		QList<QAction *> m_actions; /**< Contextual actions */
		
		// File related
		QTextDecoder *m_fileDecoder;
		KIO::TransferJob *m_transfer;
		QString m_fileData; /**< The file contents */
		
		// Process related
		QTextDecoder *m_stdoutDecoder, *m_stderrDecoder;
		QString m_stdout; /**< The process Standard Output */
		QString m_stderr; /**< The process Standard Error */
		QString m_combined; /**< The combined stderr and stdout */
		QString m_status; /**< A message describing the exit status */
		
		void clearAll ();
		void saveConfiguration ();
		bool loadConfiguration ();
		void applyConfig ( bool reload = true );
		void showProcessOutput ();
		
		QString format ( const QString & ) const;
	
	/**** Workarounds section ****/
	protected:
		void constraintsEvent ( Plasma::Constraints );

	private:
		bool m_inPanel; /**< True if the applet is in the panel, false otherwise */
		QSizeF m_sizeInDesktop; /**< The size of the applet when in desktop :-) */
		void sizeWorkaround (); /**< Redimension the size of the applet */
};

#endif